diff --git a/MQ/mcbm/CbmDeviceBmonMonitor.h b/MQ/mcbm/CbmDeviceBmonMonitor.h
index 2f285562d401e5ba1e3431be5afea8ef6b4f4158..d9ea1bd0d9bea29a21c96d18d45e077adc1fed98 100644
--- a/MQ/mcbm/CbmDeviceBmonMonitor.h
+++ b/MQ/mcbm/CbmDeviceBmonMonitor.h
@@ -223,10 +223,10 @@ private:
     std::clock_t cpuendtime = std::clock();
     auto wallendtime        = std::chrono::high_resolution_clock::now();
 
-    // Cpu time in [µs]
+    // Cpu time in [mus]
     auto cputime = 1e6 * (cpuendtime - cpustarttime) / CLOCKS_PER_SEC;
     algo->AddCpuTime(cputime);
-    // Real time in [µs]
+    // Real time in [mus]
     auto walltime = std::chrono::duration<double, std::micro>(wallendtime - wallstarttime).count();
     algo->AddWallTime(walltime);
 
@@ -234,7 +234,7 @@ private:
     // Check some numbers from this timeslice
     size_t nDigis = digivec.size();
     LOG(debug) << "Component " << icomp << " connected to config " << config->GetName() << "   n-Digis " << nDigis
-               << " processed in walltime(cputime) = " << walltime << "(" << cputime << cputime << ") µs"
+               << " processed in walltime(cputime) = " << walltime << "(" << cputime << cputime << ") micro s"
                << "this timeslice.";
 
     if (fDoPerfProf) {
diff --git a/MQ/mcbm/CbmDeviceUnpack.h b/MQ/mcbm/CbmDeviceUnpack.h
index 1c4eee48ffd6c0476163db235dd18beeb043ddbb..acfdfdb719f7210475acb9f63d0854ac9022588f 100644
--- a/MQ/mcbm/CbmDeviceUnpack.h
+++ b/MQ/mcbm/CbmDeviceUnpack.h
@@ -271,10 +271,10 @@ private:
     std::clock_t cpuendtime = std::clock();
     auto wallendtime        = std::chrono::high_resolution_clock::now();
 
-    // Cpu time in [µs]
+    // Cpu time in [mus]
     auto cputime = 1e6 * (cpuendtime - cpustarttime) / CLOCKS_PER_SEC;
     algo->AddCpuTime(cputime);
-    // Real time in [µs]
+    // Real time in [mus]
     auto walltime = std::chrono::duration<double, std::micro>(wallendtime - wallstarttime).count();
     algo->AddWallTime(walltime);
 
@@ -282,7 +282,7 @@ private:
     // Check some numbers from this timeslice
     size_t nDigis = digivec.size();
     LOG(debug) << "Component " << icomp << " connected to config " << config->GetName() << "   n-Digis " << nDigis
-               << " processed in walltime(cputime) = " << walltime << "(" << cputime << cputime << ") µs"
+               << " processed in walltime(cputime) = " << walltime << "(" << cputime << cputime << ") micro s"
                << "this timeslice.";
 
     if (fDoPerfProf) {
diff --git a/algo/detectors/bmon/UnpackMS.cxx b/algo/detectors/bmon/UnpackMS.cxx
index 22d56e90d1aee148e917555fa5a3bd1019f3d950..275ea3cb0dbe9e8587d06864a1c78d9a073c12f6 100644
--- a/algo/detectors/bmon/UnpackMS.cxx
+++ b/algo/detectors/bmon/UnpackMS.cxx
@@ -32,7 +32,7 @@ namespace cbm::algo::bmon
 
     L_(debug) << "EQ ID 0x" << std::hex << msDescr.eq_id << std::dec;
 
-    // --- Number of messages in microslice
+    // --- Number of messages in microslice
     auto msSize = msDescr.size;
     if (msSize % sizeof(critof001::Message) != 0) {
       std::get<1>(result).fNumErrInvalidMsSize++;
diff --git a/algo/detectors/much/UnpackMS.cxx b/algo/detectors/much/UnpackMS.cxx
index d917fa4cda746a5af02f8f2ff20485c4f755eb1c..01ded68f85899f2302a59d6cc1629ae362eec536 100644
--- a/algo/detectors/much/UnpackMS.cxx
+++ b/algo/detectors/much/UnpackMS.cxx
@@ -42,7 +42,7 @@ namespace cbm::algo::much
     time.currentEpochTime =
       0;  // Needed to make each MS independent of the previous! Will be updated in message 1 if MS OK
 
-    // --- Number of messages in microslice
+    // --- Number of messages in microslice
     auto msSize = msDescr.size;
     if (msSize % sizeof(stsxyter::Message) != 0) {
       std::get<1>(result).fNumErrInvalidMsSize++;
diff --git a/algo/detectors/sts/UnpackMS.cxx b/algo/detectors/sts/UnpackMS.cxx
index 077e3c7ab969db1a91718fbd458819466ab89211..9c8af375eda05a8bd817c11835b074425d65e1e5 100644
--- a/algo/detectors/sts/UnpackMS.cxx
+++ b/algo/detectors/sts/UnpackMS.cxx
@@ -40,7 +40,7 @@ namespace cbm::algo::sts
     auto const msTime = msDescr.idx;  // Unix time of MS in ns
     time.currentCycle = std::ldiv(msTime, fkCycleLength).quot;
 
-    // --- Number of messages in microslice
+    // --- Number of messages in microslice
     auto msSize = msDescr.size;
     if (msSize % sizeof(stsxyter::Message) != 0) {
       L_(error) << "Invalid microslice size: " << msSize;
diff --git a/algo/detectors/tof/UnpackMS.cxx b/algo/detectors/tof/UnpackMS.cxx
index 0c11fe61634648730d5a7fa5c4c7a834650ac33b..ae0a4d37caf02c70c4023041b2df327e1313615f 100644
--- a/algo/detectors/tof/UnpackMS.cxx
+++ b/algo/detectors/tof/UnpackMS.cxx
@@ -31,7 +31,7 @@ namespace cbm::algo::tof
     // --- and the epoch is a multiple of ns.
     time.currentTsTime = static_cast<uint64_t>(tTimeslice / critof001::kuEpochInNs) % critof001::kulEpochCycleEp;
 
-    // --- Number of messages in microslice
+    // --- Number of messages in microslice
     auto msSize = msDescr.size;
     if (msSize % sizeof(critof001::Message) != 0) {
       std::get<1>(result).fNumErrInvalidMsSize++;
diff --git a/algo/detectors/trd/UnpackMS.cxx b/algo/detectors/trd/UnpackMS.cxx
index 41310caaa2d241fa498ee8f4f215e86405127045..d598336a23b633e57a74c3c8eb1bd3aefd30d6af 100644
--- a/algo/detectors/trd/UnpackMS.cxx
+++ b/algo/detectors/trd/UnpackMS.cxx
@@ -423,7 +423,7 @@ namespace cbm::algo::trd
     Result_t result = {};
 
 
-    // Digest the flags from the µSlice
+    // Digest the flags from the micro-Slice
     digestMsFlags(msDescr.flags, std::get<1>(result));
 
     size_t fMsStartTimeRel = (msDescr.idx - tTimeslice);
@@ -462,25 +462,25 @@ namespace cbm::algo::trd
 
     MsContext ctx = {};
 
-    // Get the µSlice starttime relative to the timeslice starttime (constant is clock length of Spadic in ns)
+    // Get the micro-Slice starttime relative to the timeslice starttime (constant is clock length of Spadic in ns)
     ctx.fMsStartTimeRelCC = (msDescr.idx - tTimeslice) / fAsicClockCycle;
 
     // We only want to count on TS_MSB per Stream per TS_MSB package (each eLink sends its own TS_MSB frame)
     // so we store the current TS_MSB and compare it to the incoming.
     std::int8_t currTsMsb = 0;
 
-    // Reset the TS_MSB counter for the new µSlice we unpack
+    // Reset the TS_MSB counter for the new micro-Slice we unpack
     ctx.fNrTsMsbVec.resize(fStreamsPerWord);
 
 
-    // Get the µslice size in bytes to calculate the number of completed words
+    // Get the micro-slice size in bytes to calculate the number of completed words
     auto mssize = msDescr.size;
 
-    // Get the hardware ids from which the current µSlice is coming
+    // Get the hardware ids from which the current micro-Slice is coming
     std::uint8_t crobId = 0;
     auto criId          = msDescr.eq_id;
 
-    // Digest the flags from the µSlice
+    // Digest the flags from the micro-Slice
     digestMsFlags(msDescr.flags, std::get<1>(result));
 
     // Get the number of complete words in the input MS buffer.
@@ -491,7 +491,7 @@ namespace cbm::algo::trd
 
     std::get<0>(result).reserve(nwords);
 
-    // Loop over all 64bit-Spadic-Words in the current µslice
+    // Loop over all 64bit-Spadic-Words in the current micro-slice
     for (std::uint32_t istream = 0; istream < fStreamsPerWord; istream++) {
       currTsMsb = -1;
       for (std::uint32_t iword = 0; iword < nwords; ++iword) {
diff --git a/algo/evselector/DigiEventSelector.h b/algo/evselector/DigiEventSelector.h
index a8ba4d7a956157aca6d7795e6a50e0cac474e25c..f12fd4ccd2abd2826289f88479d66a189abefd50 100644
--- a/algo/evselector/DigiEventSelector.h
+++ b/algo/evselector/DigiEventSelector.h
@@ -17,7 +17,7 @@ namespace cbm::algo::evbuild
 {
 
   /** @struct DigiEventSelectorParams
-   ** @author Dominik Smith <d.smith@ gsi.de>
+   ** @author Dominik Smith <d.smith@gsi.de>
    ** @author Shreya Roy <s.roy@gsi.de>
    ** @author Volker Friese <v.friese@gsi.de>
    ** @since 26.01.2023
@@ -29,7 +29,7 @@ namespace cbm::algo::evbuild
 
 
   /** @class DigiEventSelector
-   ** @author Dominik Smith <d.smith@ gsi.de>
+   ** @author Dominik Smith <d.smith@gsi.de>
    ** @author Shreya Roy <s.roy@gsi.de>
    ** @author Volker Friese <v.friese@gsi.de>
    ** @since 26.01.2023
diff --git a/algo/evselector/DigiEventSelectorConfig.h b/algo/evselector/DigiEventSelectorConfig.h
index fa97bdcc13ac1475324f341217e1bc8a7300fcb7..c26fc3b73d4d54076911f67294fd8b557880e1fb 100644
--- a/algo/evselector/DigiEventSelectorConfig.h
+++ b/algo/evselector/DigiEventSelectorConfig.h
@@ -22,7 +22,7 @@ namespace cbm::algo::evbuild
 
   /** @class DigiEventSelectorConfig
    ** @brief Configuration of the DigiEventSelector class
-   ** @author Dominik Smith <d.smith@ gsi.de>
+   ** @author Dominik Smith <d.smith@gsi.de>
    ** @author Shreya Roy <s.roy@gsi.de>
    ** @author Volker Friese <v.friese@gsi.de>
    ** @since 26.01.2023
diff --git a/analysis/PWGDIL/dimuon/CbmAnaDimuonAnalysis.cxx b/analysis/PWGDIL/dimuon/CbmAnaDimuonAnalysis.cxx
index d83ff362d8973d1e7eba7bc76d12b12382ea6af4..51970260f6ce4a42da58f1aed334833155932b72 100644
--- a/analysis/PWGDIL/dimuon/CbmAnaDimuonAnalysis.cxx
+++ b/analysis/PWGDIL/dimuon/CbmAnaDimuonAnalysis.cxx
@@ -1012,7 +1012,7 @@ void CbmAnaDimuonAnalysis::Exec(Option_t* /*opt*/)
   fEvent++;
 }
 // -------------------------------------------------------------------------
-// used default ANN (16 neurons) weights generated for 8 GeV/c Au beam (UrQMD) and omega->µµ (PLUTO)
+// used default ANN (16 neurons) weights generated for 8 GeV/c Au beam (UrQMD) and omega->MuonMuon (PLUTO)
 // sis100_muon_lmvm setup
 //
 Double_t CbmAnaDimuonAnalysis::CalculateAnnValue(CbmAnaMuonCandidate* mu)
diff --git a/core/data/sts/CbmStsTrack.h b/core/data/sts/CbmStsTrack.h
index 76f34d40d125196bb9a05996f618454483b5ce56..b8943b392d7321b5f22fb67e4a8207f1460c35b6 100644
--- a/core/data/sts/CbmStsTrack.h
+++ b/core/data/sts/CbmStsTrack.h
@@ -135,7 +135,7 @@ private:
   /** Impact parameter of track at target z, in units of its error **/
   Double32_t fB;
 
-  /** median dE/dx [e/300µm] **/
+  /** median dE/dx [e/300mum] **/
   float fELoss {-1.f};
 
   /** Hide this method of the base class because it is confusing. It is valid only for STS hits 
diff --git a/core/data/tof/CbmTofDetectorId.cxx b/core/data/tof/CbmTofDetectorId.cxx
index 5d43f0b6915fd89b1f68df3f2cd03703bba2daef..9d03bc9ef489e9609fe2c8ff633f4eb74346bd62 100644
--- a/core/data/tof/CbmTofDetectorId.cxx
+++ b/core/data/tof/CbmTofDetectorId.cxx
@@ -12,7 +12,7 @@
 
 /**
  * C++ version 0.4 char* style "itoa":
- * Written by Lukás Chmela
+ * Written by Lukxs Chmela
  * Released under GPLv3.
  */
 //char* CbmTofDetectorId::itoa(int value, char* result, int base) {
diff --git a/core/detectors/mvd/SensorDataSheets/CbmMvdSensorDataSheet.cxx b/core/detectors/mvd/SensorDataSheets/CbmMvdSensorDataSheet.cxx
index c5c872bf441d9c9c33d71e2078cf3a6ed5ad361e..78a3a011db7db2a13e63f329e27b03fdc51d2ea2 100644
--- a/core/detectors/mvd/SensorDataSheets/CbmMvdSensorDataSheet.cxx
+++ b/core/detectors/mvd/SensorDataSheets/CbmMvdSensorDataSheet.cxx
@@ -68,10 +68,10 @@ std::string CbmMvdSensorDataSheet::ToString() const
   ss << " Technical Data:" << endl;
   ss << "--------------------------" << endl;
   ss << "Name of the sensor: " << fMimosaName << endl;
-  ss << "Pixel pitch (x/y) [µm]: " << fPixelPitchY * 1e4 << "/" << fPixelPitchY * 1e-4 << endl;
+  ss << "Pixel pitch (x/y) [micro m]: " << fPixelPitchY * 1e4 << "/" << fPixelPitchY * 1e-4 << endl;
   ss << "N Pixels (rows/cols): " << fNPixelsX << "/" << fNPixelsY << endl;
-  ss << "Thickness of active volume[µm]: " << fEpiTh * 1e4 << endl;
-  ss << "Integration time [µs]: " << fIntegrationTime * 1e6 << endl;
+  ss << "Thickness of active volume[ micro m]: " << fEpiTh * 1e4 << endl;
+  ss << "Integration time [micro s]: " << fIntegrationTime * 1e6 << endl;
   ss << "ADC resolution: " << fAdcBits << "bit ADC (1 = discriminator)" << endl;
   ss << "Default noise [e ENC]: " << fNoise << endl;
   ss << "Matrix size (x/y) [cm]: " << fPixelPitchX * fNPixelsX << " / " << fPixelPitchY * fNPixelsY << endl;
diff --git a/core/detectors/trd/CbmMcbm2020TrdTshiftPar.cxx b/core/detectors/trd/CbmMcbm2020TrdTshiftPar.cxx
index f0778d6247ec0e9d01eee1200f22758e0eeddcd5..24dda6e75ddc554e8c101cee80554dbe884478bf 100644
--- a/core/detectors/trd/CbmMcbm2020TrdTshiftPar.cxx
+++ b/core/detectors/trd/CbmMcbm2020TrdTshiftPar.cxx
@@ -147,14 +147,14 @@ bool CbmMcbm2020TrdTshiftPar::GetTimeshifts(std::shared_ptr<TH2> timeshiftHisto)
       fTimeshifts.Set(nentries);
 
       // Then write the eventId correlated to the tsIdx to the array
-      // For mCbm2020 a timeslice contains 10 µslices, the tsidx jumps accordingly by 10, e.g. tsidx0 = 7 -> tsidx = 17
+      // For mCbm2020 a timeslice contains 10 micro-slices, the tsidx jumps accordingly by 10, e.g. tsidx0 = 7 -> tsidx = 17
       eventId             = tsidx / 10;
       fTimeshifts[ientry] = eventId;
       ientry++;
       // Followed by the channelwise shift values
       for (size_t ichannel = 0; ichannel < fgNchannels; ichannel++) {
         tshift = fvecCurrentTimeshifts[ichannel];
-        // The above represents the timeshift in multiples of a µSlice length (for mCbm 2020 1280 ns) since here we have time to do the calculation of the actual timeshift, we do it here and not in the unpacker algo.
+        // The above represents the timeshift in multiples of a micro-Slice length (for mCbm 2020 1280 ns) since here we have time to do the calculation of the actual timeshift, we do it here and not in the unpacker algo.
         tshift *= fgMicroSliceLength;
         fTimeshifts.AddAt(tshift, ientry);
         ientry++;
diff --git a/core/detectors/trd/CbmTrdRadiator.h b/core/detectors/trd/CbmTrdRadiator.h
index 0d802d57f40f062cfee2ee0eda82f73ae05fc0a4..f158045b9ee346d5d1262bd447764ff5a61e591e 100644
--- a/core/detectors/trd/CbmTrdRadiator.h
+++ b/core/detectors/trd/CbmTrdRadiator.h
@@ -48,8 +48,8 @@ public:
   CbmTrdRadiator(Bool_t SimpleTR, TString prototype, TString window = "Kapton");
   /* // implemented prototypes are:
      "tdr18"		153x2mm PE foam foil layer (146 layers in box, 7 layers in carbon grid)       
-     "B++"		POKALON 24µm, 0.7mm gap,  350 foils
-     "K++"		POKALON 24µm, 0.7mm gap,  350 foils micro-structured
+     "B++"		POKALON 24mum, 0.7mm gap,  350 foils
+     "K++"		POKALON 24mum, 0.7mm gap,  350 foils micro-structured
      "G30"		30xfiber layer
     
      
@@ -57,7 +57,7 @@ public:
      where ci are planar components. e.g. Al;C;Air;C;Al is the TRD-2D sandwich
      There are two shortcuts for the Munster detector namely:
      "Mylar" - simple mylar window
-     "Kapton" - Al(50nm)kapton(25µm )
+     "Kapton" - Al(50nm)kapton(25mum )
   */
 
   /** Destructor **/
diff --git a/fles/mcbm2018/unpacker/CbmMcbm2018UnpackerAlgoRich.cxx b/fles/mcbm2018/unpacker/CbmMcbm2018UnpackerAlgoRich.cxx
index 1d8fbfa6fe7342fc10513fe7c49ec0ee964f539e..772822d02917bf8ef4d4d7e16bd2b8cdd6b11c28 100644
--- a/fles/mcbm2018/unpacker/CbmMcbm2018UnpackerAlgoRich.cxx
+++ b/fles/mcbm2018/unpacker/CbmMcbm2018UnpackerAlgoRich.cxx
@@ -662,7 +662,7 @@ void CbmMcbm2018UnpackerAlgoRich::ErrorMsg(uint16_t errbits, CbmMcbm2018RichErro
 
   if (type == CbmMcbm2018RichErrorType::tdcHeader) {
     // Errors description in TRB manual section 11.3.2. TDC HEADER
-    // Bit 0: min. 1 rinǵ buffer overwritten
+    // Bit 0: min. 1 ring buffer overwritten
     int nofHeaderErrorBits       = 1;
     int histBinOffsetHeaderError = 0;
     for (int i = 0; i < nofHeaderErrorBits; i++) {
diff --git a/fles/mcbm2018/unpacker/CbmMcbm2018UnpackerAlgoTrdR.h b/fles/mcbm2018/unpacker/CbmMcbm2018UnpackerAlgoTrdR.h
index b794cf25f683476b53ffae06831e7f509a1bd701..605d0808f8e2cdf2c30403ca7af6fe99551c299e 100644
--- a/fles/mcbm2018/unpacker/CbmMcbm2018UnpackerAlgoTrdR.h
+++ b/fles/mcbm2018/unpacker/CbmMcbm2018UnpackerAlgoTrdR.h
@@ -238,10 +238,10 @@ private:
   ///< Map to retrieve module channelId from asicAddress and asicChannel
 
   std::map<size_t, std::vector<Int_t>> fmapTimeshifts = {};
-  ///< Map containing the timeshift parameters for the correction of the µSlice timeshifts. The keys are the tsIdx, if no key is found, the shifts of the previous tsIdx are still valid
+  ///< Map containing the timeshift parameters for the correction of the micro-Slice timeshifts. The keys are the tsIdx, if no key is found, the shifts of the previous tsIdx are still valid
 
   std::vector<Int_t>* fvecTimeshiftsPar = nullptr;
-  ///< Vector containing the timeshift parameters for the correction of the µSlice timeshifts for a given tsIdx.
+  ///< Vector containing the timeshift parameters for the correction of the micro-Slice timeshifts for a given tsIdx.
 
   bool
     fIsFirstChannelsElinkEven;  ///< define if the first 16 channels (00..15) are found on the even (set true) or odd (false) eLinkId, default for mCbm2020 is false thus, initialized as false
diff --git a/fles/star2019/eventbuilder/CbmTofStarData2019.cxx b/fles/star2019/eventbuilder/CbmTofStarData2019.cxx
index 8648c4e6cf26294ecf9d1033df2a219ba74b830f..554eeb1ca48209c775aa14536b6190805407856a 100644
--- a/fles/star2019/eventbuilder/CbmTofStarData2019.cxx
+++ b/fles/star2019/eventbuilder/CbmTofStarData2019.cxx
@@ -166,7 +166,7 @@ void* CbmTofStarSubevent2019::BuildOutput(Int_t& iOutputSizeBytes)
                 + (static_cast<ULong64_t>(fTrigger.GetStarTrigCmd()));
   fpulBuff[3] = fulEventStatusFlags;
 
-  // does not work due to "error: cannot convert ‘gdpbv100::Message’ to ‘long unsigned int’ in assignment"
+  // does not work due to "error: cannot convert 'gdpbv100::Message' to 'long unsigned int' in assignment"
   //  std::copy( fvMsgBuffer.begin(), fvMsgBuffer.begin() + uMsgsToRead, pulBuff + 4 );
 
   // Unoptimized replacement: item by item copy
diff --git a/macro/L1/run_reco_LITglobal.C b/macro/L1/run_reco_LITglobal.C
index 75ec5e8e3ee4835a82d94bdc96f825c2bdd5aa83..884cca0981de7439e5ffd503137ffa244c547606 100644
--- a/macro/L1/run_reco_LITglobal.C
+++ b/macro/L1/run_reco_LITglobal.C
@@ -461,7 +461,7 @@ void run_reco_LITglobal(TString input = "", Int_t nTimeSlices = -1, Int_t firstT
 
   else {
 
-    // -----   Event building from STS tracks   -----------------------------
+    // -----   Event building from STS tracks   -----------------------------
     run->AddTask(new CbmBuildEventsFromTracksReal());
     // ----------------------------------------------------------------------
 
diff --git a/macro/analysis/conversion2/run_analysis.C b/macro/analysis/conversion2/run_analysis.C
index eab8068897959d6cb04e50ea05645f0e9817421a..8a4b25bfeaa7a4eb92f94d70a1fbe67d86d4a5fa 100644
--- a/macro/analysis/conversion2/run_analysis.C
+++ b/macro/analysis/conversion2/run_analysis.C
@@ -133,11 +133,11 @@ void run_analysis(Int_t nEvents = 2, TString setupName = "sis100_electron", cons
   }
   run->AddTask(l1);
 
-  // —----------------------------------------------------------------------
+  // -----------------------------------------------------------------------
   ///// add you task here
   CbmKresConversionMain* conversionKres = new CbmKresConversionMain();
   run->AddTask(conversionKres);
-  // —----------------------------------------------------------------------
+  // -----------------------------------------------------------------------
 
 
   // -----  Parameter database   --------------------------------------------
diff --git a/macro/much/run_ana.C b/macro/much/run_ana.C
index 90f470a6a81c91b22091eacfda2e77c8b3e978d9..1a7da37e57c2a6e3728cac31e3dda18d69da5b67 100644
--- a/macro/much/run_ana.C
+++ b/macro/much/run_ana.C
@@ -46,7 +46,7 @@ void run_ana(Int_t nEvents = 1000, TString dataSet = "muons", TString setup = "s
   // CbmSetup::Instance()->SetModule(ESystemId, const char*, Bool_t) or
   // CbmSetup::Instance()->SetActive(ESystemId, Bool_t)
   // See the class documentation of CbmSetup.
-  // ————————————————————————————————————
+  // ------------------------------------------------------------------------
 
 
   // ------------------------------------------------------------------------
diff --git a/macro/rich/mcbm/MAPMTtoDiRICH.info b/macro/rich/mcbm/MAPMTtoDiRICH.info
index 3b5aea401639191a33789c81762d36786fd8c834..46451e0d72747c9384926c27f69aff42e08b0ea8 100644
--- a/macro/rich/mcbm/MAPMTtoDiRICH.info
+++ b/macro/rich/mcbm/MAPMTtoDiRICH.info
@@ -42,7 +42,7 @@ DiRICH channel to MAPMT pixel for a normal MAPMT
    |15|13|11|09|07|05|03|01|
    '--'--'--'--'--'--'--'--'
 
-DiRICH channel to MAPMT pixel for a 180° rotated MAPMT
+DiRICH channel to MAPMT pixel for a 180 degree rotated MAPMT
 - 0 is a DiRICH with address 0x7**0
 - 1 is a DiRICH with address 0x7**1
 (PMTs near PowerModule)
diff --git a/macro/rich/run/run_reco.C b/macro/rich/run/run_reco.C
index 7eb1e7e2cbd5d8c2a43d2c763405e21ff0646f1f..db5751d50eefca9235a0844a478aa117c25a27d7 100644
--- a/macro/rich/run/run_reco.C
+++ b/macro/rich/run/run_reco.C
@@ -377,7 +377,7 @@ void run_reco(TString traFile = "", TString parFile = "", TString digiFile = "",
       run->AddTask(richReco);
       std::cout << "-I- " << myName << ": Added task " << richReco->GetName() << std::endl;
     }
-    // -----   Event building from STS tracks   -----------------------------
+    // -----   Event building from STS tracks   -----------------------------
     run->AddTask(new CbmBuildEventsFromTracksReal());
     // ----------------------------------------------------------------------
     //FIXME: if placing rich reco here:
diff --git a/macro/run/run_reco.C b/macro/run/run_reco.C
index 08076b858509166b897f32ed871b35bb18ad9111..9c11ddf9110ca22bab58f66c89056249578e7692 100644
--- a/macro/run/run_reco.C
+++ b/macro/run/run_reco.C
@@ -519,7 +519,7 @@ void run_reco(TString input = "", Int_t nTimeSlices = -1, Int_t firstTimeSlice =
 
   else {
 
-    // -----   Event building from STS tracks   -----------------------------
+    // -----   Event building from STS tracks   -----------------------------
     run->AddTask(new CbmBuildEventsFromTracksReal());
     // ----------------------------------------------------------------------
 
diff --git a/macro/tof/beamtime/feb15/current/FileListDef.h b/macro/tof/beamtime/feb15/current/FileListDef.h
index 650d7097a4dddec51e5f34d3e7cde91189883f19..b4e7be2084cb4fb0dfef06ce636d464891a8d790 100644
--- a/macro/tof/beamtime/feb15/current/FileListDef.h
+++ b/macro/tof/beamtime/feb15/current/FileListDef.h
@@ -89,8 +89,8 @@ Int_t iBdIdxTrdPos[kiNbTrd] = {10, 10, 10, 10, 10};
 Int_t iChIdxTrdPos[kiNbTrd] = {0, 1, 2, 3, 4};
 
 const Int_t kiSpillDistSec      = 30;    // Approximate value, now just default
-const Double_t kdSpillDiamThr   = 1e-4;  // µA
-const Double_t kdNoSpillDiamThr = 1e-5;  // µA
+const Double_t kdSpillDiamThr   = 1e-4;  // microA
+const Double_t kdNoSpillDiamThr = 1e-5;  // microA
 
 void PrintHelp()
 {
diff --git a/macro/tof/beamtime/nov15/current/FileListDef.h b/macro/tof/beamtime/nov15/current/FileListDef.h
index 1d06f7e760b88f1802891b90754d6c670efdbd8c..9f5d0d56a48321929a76fb4d8b307d1beb8fd955 100644
--- a/macro/tof/beamtime/nov15/current/FileListDef.h
+++ b/macro/tof/beamtime/nov15/current/FileListDef.h
@@ -69,8 +69,8 @@ Int_t   iChIdxTrdPos[kiNbTrd] = {       0 ,         1 ,         2 ,         3 ,
 */
 
 const Int_t kiSpillDistSec      = 30;    // Approximate value, now just default
-const Double_t kdSpillDiamThr   = 1e-4;  // µA
-const Double_t kdNoSpillDiamThr = 1e-5;  // µA
+const Double_t kdSpillDiamThr   = 1e-4;  // microA
+const Double_t kdNoSpillDiamThr = 1e-5;  // microA
 
 void PrintHelp()
 {
diff --git a/reco/base/CbmRecoUnpackAlgo.tmpl b/reco/base/CbmRecoUnpackAlgo.tmpl
index f87f534bd0244252edaa13477b199dfe4e3697a3..db72ca36c1ea2d810c439edae993df0fdcfb32ba 100644
--- a/reco/base/CbmRecoUnpackAlgo.tmpl
+++ b/reco/base/CbmRecoUnpackAlgo.tmpl
@@ -123,10 +123,10 @@ protected:
   /** @brief counter of created raw messages */
   size_t fNrEpochMsgs = 0;
 
-  /** @brief Sum counter for used cpu time by this algo [µs].*/
+  /** @brief Sum counter for used cpu time by this algo [mus].*/
   double fSumCpuTime = 0;
 
-  /** @brief Sum counter for used wall time by this algo [µs].*/
+  /** @brief Sum counter for used wall time by this algo [mus].*/
   double fSumWallTime = 0;
 
   /** @brief Sum counter for size of the input data of this algo.*/
@@ -135,13 +135,13 @@ protected:
   /** @brief Sum counter for size of the output data of this algo.*/
   double fSumOutDataSize = 0;
 
-  /** @brief counter for inf/error flags from the µSlices */
+  /** @brief counter for inf/error flags from the micro-Slices */
   size_t fNrCrcValidFlags = 0;
-  /** @brief counter for inf/error flags from the µSlices */
+  /** @brief counter for inf/error flags from the micro-Slices */
   size_t fNrOverflowFlimFlags = 0;
-  /** @brief counter for inf/error flags from the µSlices */
+  /** @brief counter for inf/error flags from the micro-Slices */
   size_t fNrOverflowUserFlags = 0;
-  /** @brief counter for inf/error flags from the µSlices */
+  /** @brief counter for inf/error flags from the micro-Slices */
   size_t fNrDataErrorFlags = 0;
 
   /** @brief Time of the last succesful digest hit message */
@@ -249,7 +249,7 @@ protected:
    * @return true
    * @return false
    *
-   * @remark The content of the µslice can only be accessed via the timeslice. Hence, we need to pass the pointer to the full timeslice
+   * @remark The content of the micro-slice can only be accessed via the timeslice. Hence, we need to pass the pointer to the full timeslice
   */
   virtual bool unpack(const fles::Timeslice* ts, std::uint16_t icomp, UInt_t imslice) = 0;
 
@@ -286,14 +286,14 @@ public:
     LOG(info) << fName << "::Finish.-------------------------\n Unpack process : \n " << fNrProcessedTs
               << " Timeslices with \n " << fNrCreatedRawMsgs << " Raw Messages,\n " << fNrCreatedDigis
               << " Digis \n ...processed in walltime(cputime) " << std::setprecision(4) << fSumWallTime << "("
-              << std::setprecision(4) << fSumCpuTime << ") µs \n "
+              << std::setprecision(4) << fSumCpuTime << ") micro s \n "
               << "-->" << std::setprecision(4) << fNrCreatedDigis / fSumWallTime << "(" << std::setprecision(4)
-              << fNrCreatedDigis / fSumCpuTime << ") Digis/µs <--> " << std::setprecision(4)
+              << fNrCreatedDigis / fSumCpuTime << ") Digis/micro s <--> " << std::setprecision(4)
               << fSumWallTime / fNrCreatedDigis << "(" << std::setprecision(4) << fSumCpuTime / fNrCreatedDigis
-              << ") µs/Digi.\n "
+              << ") micro s/Digi.\n "
               << "Processed amount of input data " << std::setprecision(4) << fSumInDataSize << " MB digested to "
               << fSumOutDataSize << " MB output data <--> " << std::setprecision(4) << fSumInDataSize / fSumWallTime
-              << " MB/µs digested. \n";
+              << " MB/ micro s digested. \n";
 
 
     LOG(debug) << fNrEpochMsgs << " Epoch Messages,\n " << fNrCreatedInfoMsgs << " Info Messages.\n "
@@ -374,7 +374,7 @@ public:
 
   // Setters
   /**
-   * @brief Set the Do Ignore Overlapp µslices flag
+   * @brief Set the Do Ignore Overlapp micro-slices flag
    *
    * @param value
   */
diff --git a/reco/detectors/bmon/unpack/CbmBmonUnpackAlgo.h b/reco/detectors/bmon/unpack/CbmBmonUnpackAlgo.h
index 27767c0371dee67a15b33228f2fb1e33cfa5946a..f82c9e090850453b94995c3e37272db0385e5f5e 100644
--- a/reco/detectors/bmon/unpack/CbmBmonUnpackAlgo.h
+++ b/reco/detectors/bmon/unpack/CbmBmonUnpackAlgo.h
@@ -156,7 +156,7 @@ class CbmBmonUnpackAlgo : public CbmRecoUnpackAlgo<CbmBmonDigi, CbmErrorMessage>
 
   // Setters
   /**
-   * @brief Set the Do Ignore Overlapp µslices flag
+   * @brief Set the Do Ignore Overlapp micro-slices flag
    *
    * @param value
   */
@@ -282,7 +282,7 @@ class CbmBmonUnpackAlgo : public CbmRecoUnpackAlgo<CbmBmonDigi, CbmErrorMessage>
    * @return true
    * @return false
    *
-   * @remark The content of the µslice can only be accessed via the timeslice. Hence, we need to pass the pointer to the full timeslice
+   * @remark The content of the micro-slice can only be accessed via the timeslice. Hence, we need to pass the pointer to the full timeslice
   */
   virtual bool unpack(const fles::Timeslice* /*ts*/, std::uint16_t /*icomp*/, UInt_t /*imslice*/) { return true; }
 
diff --git a/reco/detectors/much/unpack/CbmMuchUnpackAlgo.h b/reco/detectors/much/unpack/CbmMuchUnpackAlgo.h
index 6039009d1c26bd696f67a8d53e70a7162fba1fcf..d58e42468f9564a84bdceeb6e2322fdfd3148152 100644
--- a/reco/detectors/much/unpack/CbmMuchUnpackAlgo.h
+++ b/reco/detectors/much/unpack/CbmMuchUnpackAlgo.h
@@ -162,7 +162,7 @@ class CbmMuchUnpackAlgo : public CbmRecoUnpackAlgo<CbmMuchDigi, CbmMuchDigi, Cbm
   /** @brief Initialize and transfer the informations to the parameters storage vectors */
 
   /**
-   * @brief Main loop over the sts xyter messages in the µSlices
+   * @brief Main loop over the sts xyter messages in the micro-Slices
    *
    * @param msContent
    * @param uSize
@@ -220,7 +220,7 @@ class CbmMuchUnpackAlgo : public CbmRecoUnpackAlgo<CbmMuchDigi, CbmMuchDigi, Cbm
    * @return true
    * @return false
    *
-   * @remark The content of the µslice can only be accessed via the timeslice. Hence, we need to pass the pointer to the full timeslice
+   * @remark The content of the micro-slice can only be accessed via the timeslice. Hence, we need to pass the pointer to the full timeslice
   */
   bool unpack(const fles::Timeslice* ts, std::uint16_t icomp, UInt_t imslice);
 
@@ -329,7 +329,7 @@ class CbmMuchUnpackAlgo : public CbmRecoUnpackAlgo<CbmMuchDigi, CbmMuchDigi, Cbm
   /** @brief Potential (online) monitor for the unpacking process */
   std::shared_ptr<CbmMuchUnpackMonitor> fMonitor = nullptr;
 
-  /** @brief Current µSlice time */
+  /** @brief Current micro-Slice time */
   uint64_t fMsStartTime = 0;
 
   std::set<uint32_t> fInactiveChannels = {};
diff --git a/reco/detectors/psd/unpack/CbmPsdUnpackAlgo.h b/reco/detectors/psd/unpack/CbmPsdUnpackAlgo.h
index 17596d64835945ae2f118c4ddc41221b181bcd82..315d5155e72683f6ec9a82f3261d93a366cdcd13 100644
--- a/reco/detectors/psd/unpack/CbmPsdUnpackAlgo.h
+++ b/reco/detectors/psd/unpack/CbmPsdUnpackAlgo.h
@@ -123,7 +123,7 @@ class CbmPsdUnpackAlgo : public CbmRecoUnpackAlgo<CbmPsdDigi, CbmPsdDsp> {
    * @return true 
    * @return false 
    * 
-   * @remark The content of the µslice can only be accessed via the timeslice. Hence, we need to pass the pointer to the full timeslice
+   * @remark The content of the micro-slice can only be accessed via the timeslice. Hence, we need to pass the pointer to the full timeslice
   */
   bool unpack(const fles::Timeslice* ts, std::uint16_t icomp, UInt_t imslice);
 
diff --git a/reco/detectors/rich/CbmRichTrainAnnElectrons.cxx b/reco/detectors/rich/CbmRichTrainAnnElectrons.cxx
index 75351e5b9433243faf6a668c37585040f5faf9c6..034e24c30356ee180ed907bd03664488155f820d 100644
--- a/reco/detectors/rich/CbmRichTrainAnnElectrons.cxx
+++ b/reco/detectors/rich/CbmRichTrainAnnElectrons.cxx
@@ -134,7 +134,7 @@ CbmRichTrainAnnElectrons::CbmRichTrainAnnElectrons()
                                 -2., 2., 50, 0., 6.3);
     fHists.push_back(fhPhiVsRadAng[i]);
     // ANN outputs
-    fhAnnOutput[i] = new TH1D(string("fhAnnOutput" + ss).c_str(), "ANN output;ANN output;Counte©r", 100, -1.2, 1.2);
+    fhAnnOutput[i] = new TH1D(string("fhAnnOutput" + ss).c_str(), "ANN output;ANN output;Counter", 100, -1.2, 1.2);
     fHists.push_back(fhAnnOutput[i]);
     fhCumProb[i] =
       new TH1D(string("fhCumProb" + ss).c_str(), "ANN output;ANN output;Cumulative probability", 100, -1.2, 1.2);
diff --git a/reco/detectors/rich/alignment/CbmRichCorrection.cxx b/reco/detectors/rich/alignment/CbmRichCorrection.cxx
index 3a9e4b3349a474124ad245b48efbd80c045f427e..6193ea4da4275cffdb678305be3c159b83221be2 100644
--- a/reco/detectors/rich/alignment/CbmRichCorrection.cxx
+++ b/reco/detectors/rich/alignment/CbmRichCorrection.cxx
@@ -282,7 +282,7 @@ void CbmRichCorrection::ProjectionProducer()
     //cout << "Mirror track ID = " << mirrTrackID << endl;
     if (mirrTrackID <= -1) {
       cout << "Mirror track ID <= 1 !!!" << endl;
-      cout << "----------------------------------- End of loop N°" << iMirr + 1
+      cout << "----------------------------------- End of loop N " << iMirr + 1
            << " on the mirror points. -----------------------------------" << endl
            << endl;
       continue;
@@ -400,7 +400,7 @@ void CbmRichCorrection::ProjectionProducer()
         cout << "Not a mother particle ..." << endl;
       }
       cout << "----------------------------------- "
-           << "End of loop N°" << iMirr + 1 << " on the mirror points."
+           << "End of loop N " << iMirr + 1 << " on the mirror points."
            << " -----------------------------------" << endl
            << endl;
     }
diff --git a/reco/detectors/rich/alignment/CbmRichCorrectionVector.cxx b/reco/detectors/rich/alignment/CbmRichCorrectionVector.cxx
index 3822017351a2c1c6c76808498d797dc8cf9b9e9a..d7fe6765f13cb97b2a2e374ffdf9df9efcb95c12 100644
--- a/reco/detectors/rich/alignment/CbmRichCorrectionVector.cxx
+++ b/reco/detectors/rich/alignment/CbmRichCorrectionVector.cxx
@@ -575,7 +575,7 @@ void CbmRichCorrectionVector::ProjectionProducer(TClonesArray* projectedPoint)
     //cout << "Mirror track ID = " << mirrTrackID << endl;
     if (mirrTrackID <= -1) {
       cout << "Mirror track ID <= 1 !!!" << endl;
-      cout << "----------------------------------- End of loop N°" << iMirr + 1
+      cout << "----------------------------------- End of loop N " << iMirr + 1
            << " on the mirror points. -----------------------------------" << endl
            << endl;
       continue;
@@ -685,7 +685,7 @@ void CbmRichCorrectionVector::ProjectionProducer(TClonesArray* projectedPoint)
         cout << "Not a mother particle ..." << endl;
       }
       cout << "----------------------------------- "
-           << "End of loop N°" << iMirr + 1 << " on the mirror points."
+           << "End of loop N " << iMirr + 1 << " on the mirror points."
            << " -----------------------------------" << endl
            << endl;
     }
diff --git a/reco/detectors/rich/alignment/CbmRichPMTMapping.cxx b/reco/detectors/rich/alignment/CbmRichPMTMapping.cxx
index 54e1c911eb152893f750b0c8ce8bcb795138e4e5..157d1fe259f6e63e55d78039ad83fc7afa8d7286 100644
--- a/reco/detectors/rich/alignment/CbmRichPMTMapping.cxx
+++ b/reco/detectors/rich/alignment/CbmRichPMTMapping.cxx
@@ -445,7 +445,7 @@ void CbmRichPMTMapping::ProjectionProducer2()
     //cout << "Mirror track ID = " << mirrTrackID << endl;
     if (mirrTrackID <= -1) {
       cout << "Mirror track ID <= 1 !!!" << endl;
-      cout << "----------------------------------- End of loop N°" << iMirr + 1
+      cout << "----------------------------------- End of loop N " << iMirr + 1
            << " on the mirror points. -----------------------------------" << endl
            << endl;
       continue;
@@ -651,7 +651,7 @@ void CbmRichPMTMapping::ProjectionProducer2()
       cout << "Not a mother particle ..." << endl;
     }
     cout << "----------------------------------- "
-         << "End of loop N°" << iMirr + 1 << " on the mirror points."
+         << "End of loop N " << iMirr + 1 << " on the mirror points."
          << " -----------------------------------" << endl
          << endl;
   }
@@ -714,7 +714,7 @@ void CbmRichPMTMapping::ProjectionProducer()
     //cout << "Mirror track ID = " << mirrTrackID << endl;
     if (mirrTrackID <= -1) {
       cout << "Mirror track ID <= 1 !!!" << endl;
-      cout << "----------------------------------- End of loop N°" << iMirr + 1
+      cout << "----------------------------------- End of loop N " << iMirr + 1
            << " on the mirror points. -----------------------------------" << endl
            << endl;
       continue;
@@ -928,7 +928,7 @@ void CbmRichPMTMapping::ProjectionProducer()
       cout << "Not a mother particle ..." << endl;
     }
     cout << "----------------------------------- "
-         << "End of loop N°" << iMirr + 1 << " on the mirror points."
+         << "End of loop N " << iMirr + 1 << " on the mirror points."
          << " -----------------------------------" << endl
          << endl;
   }
diff --git a/reco/detectors/rich/mcbm/CbmRichMCbmQa.cxx b/reco/detectors/rich/mcbm/CbmRichMCbmQa.cxx
index 754c92734fe931c6e4cd401fe167b7b287dbbcf8..eb80f93b4aa8fd5aa03f198017e92a3f6d8e5cd4 100644
--- a/reco/detectors/rich/mcbm/CbmRichMCbmQa.cxx
+++ b/reco/detectors/rich/mcbm/CbmRichMCbmQa.cxx
@@ -277,7 +277,7 @@ void CbmRichMCbmQa::Exec(Option_t* /*option*/)
     Double_t timect      = 0.2998 * time;  //time in ns, timect in m
     Double_t trackLength = tofHit->GetR() / 100;
     Double_t beta        = trackLength / timect;
-    Double_t mass2       = TMath::Power(momTotal, 2.) * (TMath::Power(1 / beta, 2) - 1);  //m² = p²*((1/beta)²-1)
+    Double_t mass2       = TMath::Power(momTotal, 2.) * (TMath::Power(1 / beta, 2) - 1);  //m^2 = p^2*((1/beta)^2-1)
 
 
     for (int i = 0; i < nofRichPoints; i++) {
@@ -472,7 +472,7 @@ void CbmRichMCbmQa::Exec(Option_t* /*option*/)
             Double_t trackLength = tofHit->GetR()/100;
             Double_t beta = trackLength/timect;
 
-            Double_t mass2 = TMath::Power(momTotal, 2.) * (TMath::Power(1/beta, 2) - 1);     //m² = p²*((1/beta)²-1)
+            Double_t mass2 = TMath::Power(momTotal, 2.) * (TMath::Power(1/beta, 2) - 1);     //m^2 =p^2*((1/beta)^2-1)
 
 
             if(mcTrackIdTofHit == mcTrackIdRing){
diff --git a/reco/detectors/rich/unpack/CbmRichUnpackAlgo.h b/reco/detectors/rich/unpack/CbmRichUnpackAlgo.h
index 52c3661df614ca73d28c27a8a9c441713785221f..470fb6d106b607af6e482c76e06aba79a2419a3d 100644
--- a/reco/detectors/rich/unpack/CbmRichUnpackAlgo.h
+++ b/reco/detectors/rich/unpack/CbmRichUnpackAlgo.h
@@ -82,7 +82,7 @@ class CbmRichUnpackAlgo : public CbmRichUnpackAlgoBase {
    * @return true 
    * @return false 
    * 
-   * @remark The content of the µslice can only be accessed via the timeslice. Hence, we need to pass the pointer to the full timeslice
+   * @remark The content of the micro-slice can only be accessed via the timeslice. Hence, we need to pass the pointer to the full timeslice
   */
   bool unpack(const fles::Timeslice* ts, std::uint16_t icomp, UInt_t imslice);
 
diff --git a/reco/detectors/rich/unpack/CbmRichUnpackAlgo2022.h b/reco/detectors/rich/unpack/CbmRichUnpackAlgo2022.h
index ca6aaa6e52515970dd679ad287d7b201faed4f53..a958d39185bf3ffdd80fc1297169c58c00e2f74c 100644
--- a/reco/detectors/rich/unpack/CbmRichUnpackAlgo2022.h
+++ b/reco/detectors/rich/unpack/CbmRichUnpackAlgo2022.h
@@ -82,7 +82,7 @@ class CbmRichUnpackAlgo2022 : public CbmRichUnpackAlgoBase {
    * @return true
    * @return false
    *
-   * @remark The content of the µslice can only be accessed via the timeslice. Hence, we need to pass the pointer to the full timeslice
+   * @remark The content of the micro-slice can only be accessed via the timeslice. Hence, we need to pass the pointer to the full timeslice
   */
   bool unpack(const fles::Timeslice* ts, std::uint16_t icomp, UInt_t imslice);
 
diff --git a/reco/detectors/rich/unpack/CbmRichUnpackAlgoBase.h b/reco/detectors/rich/unpack/CbmRichUnpackAlgoBase.h
index fbec419b35fa35e70327a35168260c68bd81da8b..b28d5a6f2be53110c0378c31cfbc904f3f4f495c 100644
--- a/reco/detectors/rich/unpack/CbmRichUnpackAlgoBase.h
+++ b/reco/detectors/rich/unpack/CbmRichUnpackAlgoBase.h
@@ -307,7 +307,7 @@ class CbmRichUnpackAlgoBase : public CbmRecoUnpackAlgo<CbmRichDigi> {
    * @return true
    * @return false
    *
-   * @remark The content of the µslice can only be accessed via the timeslice. Hence, we need to pass the pointer to the full timeslice
+   * @remark The content of the micro-slice can only be accessed via the timeslice. Hence, we need to pass the pointer to the full timeslice
   */
   //bool unpack(const fles::Timeslice* ts, std::uint16_t icomp, UInt_t imslice);
 
diff --git a/reco/detectors/sts/unpack/CbmStsUnpackAlgo.h b/reco/detectors/sts/unpack/CbmStsUnpackAlgo.h
index 94a8667dd08d56a996bb15b8aa987c4ff999f587..36ba662a813ebb7d28d6976141ffb3c97fd77bf0 100644
--- a/reco/detectors/sts/unpack/CbmStsUnpackAlgo.h
+++ b/reco/detectors/sts/unpack/CbmStsUnpackAlgo.h
@@ -105,7 +105,7 @@ class CbmStsUnpackAlgo : public CbmStsUnpackAlgoBase {
                        std::vector<std::vector<bool>>* vbCrobActiveFlag,
                        std::vector<std::vector<std::vector<int32_t>>>* viFebModuleSide);
   /**
-   * @brief Main loop over the sts xyter messages in the µSlices
+   * @brief Main loop over the sts xyter messages in the micro-Slices
    *
    * @param msContent
    * @param uSize
@@ -161,12 +161,12 @@ class CbmStsUnpackAlgo : public CbmStsUnpackAlgoBase {
    * @return true
    * @return false
    *
-   * @remark The content of the µslice can only be accessed via the timeslice. Hence, we need to pass the pointer to the full timeslice
+   * @remark The content of the micro-slice can only be accessed via the timeslice. Hence, we need to pass the pointer to the full timeslice
   */
   bool unpack(const fles::Timeslice* ts, std::uint16_t icomp, UInt_t imslice);
 
   // Monitoring
-  /** @brief Current µSlice time */
+  /** @brief Current micro-Slice time */
   uint64_t fMsStartTime = 0;
 
   // Parameter members
diff --git a/reco/detectors/sts/unpack/CbmStsUnpackAlgoLegacy.h b/reco/detectors/sts/unpack/CbmStsUnpackAlgoLegacy.h
index 21f92c1ccb316e36e11dcdc6ba378ea3576abca5..08a04747afebab7003df794def5dc3c6da302a09 100644
--- a/reco/detectors/sts/unpack/CbmStsUnpackAlgoLegacy.h
+++ b/reco/detectors/sts/unpack/CbmStsUnpackAlgoLegacy.h
@@ -53,7 +53,7 @@ class CbmStsUnpackAlgoLegacy : public CbmStsUnpackAlgoBase {
    * @return true
    * @return false
    *
-   * @remark The content of the µslice can only be accessed via the timeslice. Hence, we need to pass the pointer to the full timeslice
+   * @remark The content of the micro-slice can only be accessed via the timeslice. Hence, we need to pass the pointer to the full timeslice
   */
   bool unpack(const fles::Timeslice* ts, std::uint16_t icomp, UInt_t imslice);
 
diff --git a/reco/detectors/tof/unpack/CbmTofUnpackAlgo.h b/reco/detectors/tof/unpack/CbmTofUnpackAlgo.h
index ea3346aededb134c3c204f9753c9377cb45ffa24..11458a8838d40f86d20d4455de87c73ccacb76d3 100644
--- a/reco/detectors/tof/unpack/CbmTofUnpackAlgo.h
+++ b/reco/detectors/tof/unpack/CbmTofUnpackAlgo.h
@@ -154,7 +154,7 @@ class CbmTofUnpackAlgo : public CbmRecoUnpackAlgo<CbmTofDigi, CbmErrorMessage> {
    * @return true
    * @return false
    *
-   * @remark The content of the µslice can only be accessed via the timeslice. Hence, we need to pass the pointer to the full timeslice
+   * @remark The content of the micro-slice can only be accessed via the timeslice. Hence, we need to pass the pointer to the full timeslice
   */
   bool unpack(const fles::Timeslice* ts, std::uint16_t icomp, UInt_t imslice);
 
diff --git a/reco/detectors/trd/unpack/CbmTrdUnpackAlgoBaseR.h b/reco/detectors/trd/unpack/CbmTrdUnpackAlgoBaseR.h
index 3c430596fd625c568f28312a01398329a312b9df..418a8dcb2d720fac3e699667c313386725460bbd 100644
--- a/reco/detectors/trd/unpack/CbmTrdUnpackAlgoBaseR.h
+++ b/reco/detectors/trd/unpack/CbmTrdUnpackAlgoBaseR.h
@@ -195,7 +195,7 @@ class CbmTrdUnpackAlgoBaseR : public CbmRecoUnpackAlgo<CbmTrdDigi, CbmTrdRawMess
   /** @brief Map to retrieve module channelId from asicAddress and asicChannel */
   std::map<Int_t, std::vector<Int_t>> fAsicChannelMap = {};
 
-  /** @brief Map containing the timeshift parameters for the correction of the µSlice timeshifts. The keys are the tsIdx, if no key is found, the shifts of the previous tsIdx are used again */
+  /** @brief Map containing the timeshift parameters for the correction of the micro-Slice timeshifts. The keys are the tsIdx, if no key is found, the shifts of the previous tsIdx are used again */
   std::map<size_t, std::vector<Int_t>> fTimeshiftsMap = {};
 
   /** @brief Define if the first 16 channels (00..15) are found on the even (set true) or odd (false) eLinkId.
@@ -211,7 +211,7 @@ class CbmTrdUnpackAlgoBaseR : public CbmRecoUnpackAlgo<CbmTrdDigi, CbmTrdRawMess
   /** @brief Number of missing EOM frames to finish a SOM frame */
   size_t fNrMissingEom = 0;
 
-  /** @brief Number of wild null words, should only appear at the end of a µSlice */
+  /** @brief Number of wild null words, should only appear at the end of a micro-Slice */
   size_t fNrWildNul = 0;
 
   /** @brief Number of unknown words */
diff --git a/reco/detectors/trd/unpack/CbmTrdUnpackAlgoLegacy2020R.cxx b/reco/detectors/trd/unpack/CbmTrdUnpackAlgoLegacy2020R.cxx
index 82750288b8a2bba0d12566ff8ac4f3db80784f81..fdf4c53dfdadd378e64227105bea7838a1ec7183 100644
--- a/reco/detectors/trd/unpack/CbmTrdUnpackAlgoLegacy2020R.cxx
+++ b/reco/detectors/trd/unpack/CbmTrdUnpackAlgoLegacy2020R.cxx
@@ -327,7 +327,7 @@ bool CbmTrdUnpackAlgoLegacy2020R::unpack(const fles::Timeslice* ts, std::uint16_
 
   auto msdesc = ts->descriptor(icomp, imslice);
 
-  // Get the µslice size in bytes to calculate the number of completed words
+  // Get the micro-slice size in bytes to calculate the number of completed words
   auto mssize = msdesc.size;
 
   // Get the number of complete words in the input MS buffer.
@@ -336,7 +336,7 @@ bool CbmTrdUnpackAlgoLegacy2020R::unpack(const fles::Timeslice* ts, std::uint16_
   const auto mspointer = ts->content(icomp, imslice);
   const auto mscontent = reinterpret_cast<const size_t*>(mspointer);
 
-  // Loop over all 64bit-Spadic-Words in the current µslice
+  // Loop over all 64bit-Spadic-Words in the current micro-slice
   for (std::uint32_t iword = 0; iword < msNrWords; iword++) {
     // Access the actual word from the pointer
     auto word = static_cast<size_t>(mscontent[iword]);
diff --git a/reco/detectors/trd/unpack/CbmTrdUnpackAlgoLegacy2020R.h b/reco/detectors/trd/unpack/CbmTrdUnpackAlgoLegacy2020R.h
index 4ea2439a3de4e96d15bbabfdd503cb9dd4e3202a..be19af28939738fde79b8bc4aca6271fc0230674 100644
--- a/reco/detectors/trd/unpack/CbmTrdUnpackAlgoLegacy2020R.h
+++ b/reco/detectors/trd/unpack/CbmTrdUnpackAlgoLegacy2020R.h
@@ -143,13 +143,13 @@ class CbmTrdUnpackAlgoLegacy2020R : public CbmTrdUnpackAlgoBaseR {
    * @return true 
    * @return false 
    * 
-   * @remark The content of the µslice can only be accessed via the timeslice. Hence, we need to pass the pointer to the full timeslice
+   * @remark The content of the micro-slice can only be accessed via the timeslice. Hence, we need to pass the pointer to the full timeslice
   */
   virtual bool unpack(const fles::Timeslice* ts, std::uint16_t icomp, UInt_t imslice);
 
   // Parameter storage members
 
-  /** @brief Vector containing the timeshift parameters for the correction of the µSlice timeshifts for a given tsIdx.*/
+  /** @brief Vector containing the timeshift parameters for the correction of the micro-Slice timeshifts for a given tsIdx.*/
   std::vector<std::int32_t>* fTimeshiftsParVec = nullptr;
 
   /** @brief Time of the current epoch marker */
diff --git a/reco/detectors/trd/unpack/CbmTrdUnpackAlgoR.cxx b/reco/detectors/trd/unpack/CbmTrdUnpackAlgoR.cxx
index 1860d6fbbc1d32bacace368cf04910725d8f67f8..b894c4c8918a0dc48912f0dab4026d99a593c3a2 100644
--- a/reco/detectors/trd/unpack/CbmTrdUnpackAlgoR.cxx
+++ b/reco/detectors/trd/unpack/CbmTrdUnpackAlgoR.cxx
@@ -386,16 +386,16 @@ bool CbmTrdUnpackAlgoR::unpack(const fles::Timeslice* ts, std::uint16_t icomp, U
 
   auto msdesc = ts->descriptor(icomp, imslice);
 
-  // Get the µSlice starttime relative to the timeslice starttime.
+  // Get the micro-Slice starttime relative to the timeslice starttime.
   // The UTC is already to large for storing it CbmTrdRawMessageSpadic due to a cast, caused by the multiplication with a double used in the raw message
   fMsStartTimeRel   = msdesc.idx - fTsStartTime;
   fMsStartTimeRelCC = fMsStartTimeRel / fSpadic->GetClockCycle();
 
-  // Get the hardware ids from which the current µSlice is coming
+  // Get the hardware ids from which the current micro-Slice is coming
   std::uint8_t crobId = 0;
   auto criId          = msdesc.eq_id;
 
-  // Digest the flags from the µSlice
+  // Digest the flags from the micro-Slice
   digestMsFlags(msdesc.flags, criId, crobId);
 
   const auto mspointer = ts->content(icomp, imslice);
@@ -414,13 +414,13 @@ bool CbmTrdUnpackAlgoR::unpack(const fles::Timeslice* ts, std::uint16_t icomp, U
 bool CbmTrdUnpackAlgoR::unpackRaw(const fles::MicrosliceDescriptor msdesc, const size_t* mscontent)
 {
 
-  // Get the µslice size in bytes to calculate the number of completed words
+  // Get the micro-slice size in bytes to calculate the number of completed words
   auto mssize = msdesc.size;
 
   // We have 32 bit spadic frames in this readout version
   std::uint32_t nwords = mssize / fBytesPerWord;
 
-  // Get the hardware ids from which the current µSlice is coming
+  // Get the hardware ids from which the current micro-Slice is coming
   std::uint8_t crobId = 0;
   auto criId          = msdesc.eq_id;
 
@@ -428,11 +428,11 @@ bool CbmTrdUnpackAlgoR::unpackRaw(const fles::MicrosliceDescriptor msdesc, const
   // We only want to count on TS_MSB per Stream per TS_MSB package (each eLink sends its own TS_MSB frame) so we store the current TS_MSB and compare it to the incoming.
   std::int8_t currTsMsb = 0;
 
-  // Reset the TS_MSB counter for the new µSlice we unpack
+  // Reset the TS_MSB counter for the new micro-Slice we unpack
   fNrTsMsbVec.clear();
   fNrTsMsbVec.resize(fStreamsPerWord);
 
-  // Loop over all 64bit-Spadic-Words in the current µslice
+  // Loop over all 64bit-Spadic-Words in the current micro-slice
   for (std::uint32_t istream = 0; istream < fStreamsPerWord; istream++) {
     currTsMsb = -1;
     for (std::uint32_t iword = 0; iword < nwords; ++iword) {
@@ -616,10 +616,10 @@ bool CbmTrdUnpackAlgoR::unpackFex(const fles::MicrosliceDescriptor msdesc, const
   }
   bool unpackOk = true;
 
-  // Get the µslice size in bytes to calculate the number of completed words
+  // Get the micro-slice size in bytes to calculate the number of completed words
   auto mssize          = msdesc.size;
   std::uint32_t nwords = mssize / bytes;
-  // Get the hardware ids from which the current µSlice is coming
+  // Get the hardware ids from which the current micro-Slice is coming
   std::uint8_t crobId = 0;
   auto criId          = msdesc.eq_id;
 
diff --git a/reco/detectors/trd/unpack/CbmTrdUnpackAlgoR.h b/reco/detectors/trd/unpack/CbmTrdUnpackAlgoR.h
index 8ff65e9576dcee589bef8fde7d3333b947317ff0..f6df4997fa28c8ccfada9dcdf9992dee991e9ee0 100644
--- a/reco/detectors/trd/unpack/CbmTrdUnpackAlgoR.h
+++ b/reco/detectors/trd/unpack/CbmTrdUnpackAlgoR.h
@@ -70,8 +70,8 @@ class CbmTrdUnpackAlgoR : public CbmTrdUnpackAlgoBaseR {
   /**
    * @brief Digest the aditional flags stored in the 4 "cccc" bits of the EPO messages.
    * @param frame 
-   * @param criId id of the cri that send the µSlice
-   * @param criobId id of the crob that send the µSlice (currently not used set to 0 062021 PR)
+   * @param criId id of the cri that send the micro-Slice
+   * @param criobId id of the crob that send the micro-Slice (currently not used set to 0 062021 PR)
    * @param elinkId id of the elink from which the info message frame came
    * @return Spadic::MsInfoType
   */
@@ -81,17 +81,17 @@ class CbmTrdUnpackAlgoR : public CbmTrdUnpackAlgoBaseR {
   /**
    * @brief Digest a info message run all default information forwarding from the msg.
    * @param frame 
-   * @param criId id of the cri that send the µSlice
-   * @param criobId id of the crob that send the µSlice (currently not used set to 0 062021 PR)
+   * @param criId id of the cri that send the micro-Slice
+   * @param criobId id of the crob that send the micro-Slice (currently not used set to 0 062021 PR)
    * @param elinkId id of the elink from which the info message frame came
   */
   void digestInfoMsg(const std::uint32_t frame, std::uint16_t criId, std::uint8_t crobId, std::uint16_t elinkId);
 
   /**
-   * @brief Digest the flags of the currently unpacked µSlice.
-   * @param flags flags stored in the µSlice descriptor 
-   * @param criId id of the cri that send the µSlice
-   * @param criobId id of the crob that send the µSlice (currently not used set to 0 062021 PR)
+   * @brief Digest the flags of the currently unpacked micro-Slice.
+   * @param flags flags stored in the micro-Slice descriptor 
+   * @param criId id of the cri that send the micro-Slice
+   * @param criobId id of the crob that send the micro-Slice (currently not used set to 0 062021 PR)
   */
   void digestMsFlags(const std::uint16_t flags, std::uint16_t criId, std::uint8_t crobId);
 
@@ -139,8 +139,8 @@ class CbmTrdUnpackAlgoR : public CbmTrdUnpackAlgoBaseR {
    * @brief Create a CbmTrdRawMessageSpadic from the hit message input. 
    * 
    * @param word 
-   * @param criId id of the cri that send the µSlice
-   * @param criobId id of the crob that send the µSlice (currently not used set to 0 062021 PR)
+   * @param criId id of the cri that send the micro-Slice
+   * @param criobId id of the crob that send the micro-Slice (currently not used set to 0 062021 PR)
    * @param istream
    * @return CbmTrdRawMessageSpadic 
    *
@@ -177,7 +177,7 @@ class CbmTrdUnpackAlgoR : public CbmTrdUnpackAlgoBaseR {
    * @return true 
    * @return false 
    * 
-   * @remark The content of the µslice can only be accessed via the timeslice. Hence, we need to pass the pointer to the full timeslice
+   * @remark The content of the micro-slice can only be accessed via the timeslice. Hence, we need to pass the pointer to the full timeslice
   */
   bool unpack(const fles::Timeslice* ts, std::uint16_t icomp, UInt_t imslice);
 
@@ -200,10 +200,10 @@ class CbmTrdUnpackAlgoR : public CbmTrdUnpackAlgoBaseR {
   /** @brief Number of corrupted EOM frames */
   size_t fNrCorruptEom = 0;
 
-  /** @brief Start time of the current µSlice relative to the Timeslice start time in ns. */
+  /** @brief Start time of the current micro-Slice relative to the Timeslice start time in ns. */
   size_t fMsStartTimeRel = 0;
 
-  /** @brief Start time of the current µSlice relative to the Timeslice start time in Spadic CC. */
+  /** @brief Start time of the current micro-Slice relative to the Timeslice start time in Spadic CC. */
   size_t fMsStartTimeRelCC = 0;
 
   // Constants
diff --git a/reco/detectors/trd/unpack/CbmTrdUnpackFaspAlgo.cxx b/reco/detectors/trd/unpack/CbmTrdUnpackFaspAlgo.cxx
index 9885486b6cb55126bd53a1ad8f4e8a201101dea6..db643606d1af897fcbd396fb81d1f75366b34c70 100644
--- a/reco/detectors/trd/unpack/CbmTrdUnpackFaspAlgo.cxx
+++ b/reco/detectors/trd/unpack/CbmTrdUnpackFaspAlgo.cxx
@@ -311,7 +311,7 @@ bool CbmTrdUnpackFaspAlgo::unpack(const fles::Timeslice* ts, std::uint16_t icomp
   // get MOD_id and ROB id from the equipment, using the comp map: eq_id -> (mod_id, rob_id)
   fMess->mod = fAsicSet.FindModuleByEqId(msdesc.eq_id, fMess->rob, fMess->elink);
   //printf("AB :: eq_id[0x%x] -> rob[%d] link[%d] mod[%d]\n", msdesc.eq_id, fMess->rob, fMess->elink, fMess->mod);
-  // Get the µslice size in bytes to calculate the number of completed words
+  // Get the micro-slice size in bytes to calculate the number of completed words
   auto mssize = msdesc.size;
 
   // Get the number of complete words in the input MS buffer.
diff --git a/reco/detectors/trd/unpack/CbmTrdUnpackFaspAlgo.h b/reco/detectors/trd/unpack/CbmTrdUnpackFaspAlgo.h
index 030bd7c3666d30b310eef351ce3e7d0a1acae8d5..c5e0fb6c9fd1baa13437580d3432df48e1b086dc 100644
--- a/reco/detectors/trd/unpack/CbmTrdUnpackFaspAlgo.h
+++ b/reco/detectors/trd/unpack/CbmTrdUnpackFaspAlgo.h
@@ -201,7 +201,7 @@ class CbmTrdUnpackFaspAlgo : public CbmRecoUnpackAlgo<CbmTrdDigi> {
    * @param imslice index of the microslice to be unpacked
    * @return true if all is fine
    *
-   * @remark The content of the µslice can only be accessed via the timeslice. Hence, we need to pass the pointer to the full timeslice
+   * @remark The content of the micro-slice can only be accessed via the timeslice. Hence, we need to pass the pointer to the full timeslice
   */
   bool unpack(const fles::Timeslice* ts, std::uint16_t icomp, UInt_t imslice);
 
diff --git a/reco/steer/CbmRecoUnpack.h b/reco/steer/CbmRecoUnpack.h
index c9da5be581d4bf0379c30b197677da684e5e99aa..de18bbe20d1548becc588881265387ba6ca5ad68 100644
--- a/reco/steer/CbmRecoUnpack.h
+++ b/reco/steer/CbmRecoUnpack.h
@@ -397,10 +397,10 @@ class CbmRecoUnpack : public TObject {
     std::clock_t cpuendtime = std::clock();
     auto wallendtime        = std::chrono::high_resolution_clock::now();
 
-    // Cpu time in [µs]
+    // Cpu time in [mus]
     auto cputime = 1e6 * (cpuendtime - cpustarttime) / CLOCKS_PER_SEC;
     algo->AddCpuTime(cputime);
-    // Real time in [µs]
+    // Real time in [mus]
     auto walltime = std::chrono::duration<double, std::micro>(wallendtime - wallstarttime).count();
     algo->AddWallTime(walltime);
 
@@ -408,7 +408,7 @@ class CbmRecoUnpack : public TObject {
     // Check some numbers from this timeslice
     size_t nDigis = digivec.size();
     LOG(debug) << "Component " << icomp << " connected to config " << config->GetName() << "   n-Digis " << nDigis
-               << " processed in walltime(cputime) = " << walltime << "(" << cputime << cputime << ") µs"
+               << " processed in walltime(cputime) = " << walltime << "(" << cputime << cputime << ") micro s"
                << "this timeslice.";
 
     if (fDoPerfProf) {
diff --git a/sim/detectors/mvd/plugins/tasks/CbmMvdSensorDigitizerTask.cxx b/sim/detectors/mvd/plugins/tasks/CbmMvdSensorDigitizerTask.cxx
index 3bf98a3f0dd0f3b0a482b49184f5c6f5b3cf908b..8a2932ce600cc7a1d86aeb1ed77cd4df79f3edd4 100644
--- a/sim/detectors/mvd/plugins/tasks/CbmMvdSensorDigitizerTask.cxx
+++ b/sim/detectors/mvd/plugins/tasks/CbmMvdSensorDigitizerTask.cxx
@@ -440,8 +440,8 @@ void CbmMvdSensorDigitizerTask::Exec()
       //The digitizer acts only on particles, which crossed the station.
       //Particles generated in the sensor or being absorbed in this sensor are ignored
       if (TMath::Abs(point->GetZOut() - point->GetZ()) < 0.9 * fEpiTh) {
-        LOG(debug) << "hit not on chip with thickness " << fEpiTh * 10000 << "µm";
-        LOG(debug) << "hit not on chip with length " << TMath::Abs(point->GetZOut() - point->GetZ()) * 10000 << "µm";
+        LOG(debug) << "hit not on chip with thickness " << fEpiTh * 10000 << "mu";
+        LOG(debug) << "hit not on chip with length " << TMath::Abs(point->GetZOut() - point->GetZ()) * 10000 << "mu";
         continue;
       }
       // Reject for the time being light nuclei (no digitization modell yet)
diff --git a/sim/detectors/sts/CbmStsDigitize.cxx b/sim/detectors/sts/CbmStsDigitize.cxx
index 757f08b65893ad7d5556dcabdd20bc377c9e48bd..8ca908b811db156356541546d3246e59d4f38000 100644
--- a/sim/detectors/sts/CbmStsDigitize.cxx
+++ b/sim/detectors/sts/CbmStsDigitize.cxx
@@ -479,7 +479,7 @@ void CbmStsDigitize::InitParams()
     Double_t nStripsF = dX / pitchF;
     Double_t nStripsB = dX / pitchB;
 
-    // The stereo sensors with 6.2092 cm width have 1024 strips à 58 mum.
+    // The stereo sensors with 6.2092 cm width have 1024 strips with 58 mum.
     if (fUserParSensor->GetClass() == CbmStsSensorClass::kDssdStereo && TMath::Abs(lX - 6.2092) < 0.0001
         && TMath::Abs(pitchF - 0.0058) < 0.0001) {
       nStripsF = 1024.;
diff --git a/sim/detectors/trd/CbmTrdDigitizer.cxx b/sim/detectors/trd/CbmTrdDigitizer.cxx
index 15f0a8e0f31df08513f0caaeeec763b88f80b919..432c618cf8d3dfe0b3261209b7fcc724afd4f4bf 100644
--- a/sim/detectors/trd/CbmTrdDigitizer.cxx
+++ b/sim/detectors/trd/CbmTrdDigitizer.cxx
@@ -345,21 +345,21 @@ CbmTrdModuleSim* CbmTrdDigitizer::AddModule(Int_t detId)
         //   const Char_t *ewin = "Al;C;Air;C;Al";
         const Char_t* ewin = "Al;C;HC;C;Al";
         Float_t widths[]   = {
-          1.2e-3,  // 12 µm aluminized polyester foil
+          1.2e-3,  // 12 mu aluminized polyester foil
           0.02,    // carbon laminate sheets of 0.2 mm thickness
           0.9,     // 9mm Nomex honeycom
           0.02,    // carbon laminate sheets of 0.2 mm thickness
-          1.2e-3,  // 12 µm aluminized polyester foil
+          1.2e-3,  // 12 mu aluminized polyester foil
         };
 
         //   // light TRD-2D entrance window
         //   const Char_t *ewin = "Al;C;HC;Po;Al";
         //   Float_t widths[] = {
-        //     1.2e-3, // 12 µm aluminized polyester foil
+        //     1.2e-3, // 12 mu aluminized polyester foil
         //     0.02,   // carbon laminate sheets of 0.2 mm thickness
         //     0.9,    // 9mm Nomex honeycom
-        //     0.0025, // polyethylen sheets of 50 µm thickness
-        //     1.2e-3, // 12 µm aluminized polyester foil
+        //     0.0025, // polyethylen sheets of 50 mu thickness
+        //     1.2e-3, // 12 mu aluminized polyester foil
         //   };  pwidth = widths;
         fRadiator2D = make_shared<CbmTrdRadiator>(kTRUE, "tdr18", ewin);
         fRadiator2D->SetEWwidths(5, widths);
diff --git a/sim/detectors/trd/qa/CbmTrdHitRateFastQa.cxx b/sim/detectors/trd/qa/CbmTrdHitRateFastQa.cxx
index 9f9b49953ca9900cd296a7dcc402a8fb64bc837b..4079ea301b44d80af7365a287091552c43eb5d97 100644
--- a/sim/detectors/trd/qa/CbmTrdHitRateFastQa.cxx
+++ b/sim/detectors/trd/qa/CbmTrdHitRateFastQa.cxx
@@ -1346,7 +1346,7 @@ Double_t CbmTrdHitRateFastQa::CalcHitRate(HitRateGeoPara2* GeoPara, Double_t Sta
     }
     y += yStepWidth;
   }
-  return (HitRate /*/(counter/100.)*/); /*Convertes Hits/Pad -> Hits/cm² on each Pad*/
+  return (HitRate /*/(counter/100.)*/); /*Convertes Hits/Pad -> Hits/cm^2 on each Pad*/
 }
 
 
diff --git a/sim/detectors/trd/qa/CbmTrdHitRateQa.cxx b/sim/detectors/trd/qa/CbmTrdHitRateQa.cxx
index 888031b22fdb4d64821f82d7900848db7d24c66d..531c101fd8b7b25e1fa548ed6ca76d73bf825567 100644
--- a/sim/detectors/trd/qa/CbmTrdHitRateQa.cxx
+++ b/sim/detectors/trd/qa/CbmTrdHitRateQa.cxx
@@ -967,7 +967,7 @@ Double_t CbmTrdHitRateQa::CalcHitRate(HitRateGeoPara* GeoPara, Double_t StartX,
     }
     y += yStepWidth;
   }
-  return (HitRate /*/(counter/100.)*/); /*Convertes Hits/Pad -> Hits/cm² on each Pad*/
+  return (HitRate /*/(counter/100.)*/); /*Convertes Hits/Pad -> Hits/cm^2 on each Pad*/
 }
 
 
diff --git a/sim/transport/base/CbmStackFilter.h b/sim/transport/base/CbmStackFilter.h
index c6b675270b301a0e4a9a6171d8843d2093906207..755cf0817db5f479b57af35c52247375661acf05 100644
--- a/sim/transport/base/CbmStackFilter.h
+++ b/sim/transport/base/CbmStackFilter.h
@@ -85,7 +85,7 @@ public:
 
   /** @brief Check the stack particles for fulfilling the storage criteria
      ** @param particles TClonesArray of TParticles
-     ** @param points    Map holding the number of points in each detector
+     ** @param points    Map holding the number of points in each detector
      ** @return Storage decision for each index in the TClonesArray
      **
      ** The implemented behaviour is described in the class documentation.
diff --git a/sim/transport/base/CbmTarget.cxx b/sim/transport/base/CbmTarget.cxx
index 239ea3c6b61dcea8078c863099fccb3294fe1a5c..3684853e6824f9851ddb4ca20376e178f590b054 100644
--- a/sim/transport/base/CbmTarget.cxx
+++ b/sim/transport/base/CbmTarget.cxx
@@ -205,7 +205,7 @@ Double_t CbmTarget::GetStandardDensity(Int_t charge) const
   // TODO: Better implementation with array or the like
 
   switch (charge) {
-    case 1: return 0.07085; break;  // Liquid Hydrogen (20ËšK at 1 atm)
+    case 1: return 0.07085; break;  // Liquid Hydrogen (20K at 1 atm)
     case 4: return 1.848; break;    // Beryllium
     case 6: return 2.260; break;    // Carbon
     case 28: return 8.908; break;   // Nickel
diff --git a/algo/detectors/trd/UnpackMS.h b/algo/detectors/trd/UnpackMS.h
index 35f0d874a50ef214c45d2e245d1c79b8f980171f..e7832b93ca6384e04cf0b1c7bd8a90314f03959f 100644
--- a/algo/detectors/trd/UnpackMS.h
+++ b/algo/detectors/trd/UnpackMS.h
@@ -67,11 +67,11 @@ namespace cbm::algo::trd
     size_t fNumWildEom           = 0;  ///< Number of eom frames outside of a SOM frame range
     size_t fNumUnknownWords      = 0;  ///< Number of unknown words
     size_t fNumMissingEom        = 0;  ///< Number of missing EOM frames to finish a SOM frame
-    size_t fNumWildNul           = 0;  ///< Number of wild null words, should only appear at the end of a µSlice
-    size_t fNumCrcValidFlags     = 0;  ///< counter for inf/error flags from the µSlices
-    size_t fNumOverflowFlimFlags = 0;  ///< counter for inf/error flags from the µSlices
-    size_t fNumOverflowUserFlags = 0;  ///< counter for inf/error flags from the µSlices
-    size_t fNumDataErrorFlags    = 0;  ///< counter for inf/error flags from the µSlices
+    size_t fNumWildNul           = 0;  ///< Number of wild null words, should only appear at the end of a micro-Slice
+    size_t fNumCrcValidFlags     = 0;  ///< counter for inf/error flags from the micro-Slices
+    size_t fNumOverflowFlimFlags = 0;  ///< counter for inf/error flags from the micro-Slices
+    size_t fNumOverflowUserFlags = 0;  ///< counter for inf/error flags from the micro-Slices
+    size_t fNumDataErrorFlags    = 0;  ///< counter for inf/error flags from the micro-Slices
 
     bool HasErrors()
     {
@@ -134,7 +134,7 @@ namespace cbm::algo::trd
 
    private:  // Types
     struct MsContext {
       /** @brief Start time of the current µSlice relative to the Timeslice start time in Spadic CC. */
       size_t fMsStartTimeRelCC = 0;
 
       /** @brief Time of the last succesful digest hit message */
@@ -162,8 +162,8 @@ namespace cbm::algo::trd
     Spadic::MsInfoType digestBufInfoFlags(const std::uint32_t frame) const;
 
     /**
      ** @brief Digest the flags of the currently unpacked µSlice.
      ** @param flags flags stored in the µSlice descriptor
      ** @param storage of monitoring data
      **/
     void digestMsFlags(const std::uint16_t flags, UnpackMonitorData& monitor) const;
@@ -208,8 +208,8 @@ namespace cbm::algo::trd
     /**
      ** @brief Create a CbmTrdRawMessageSpadic from the hit message input.
      ** @param word
      ** @param criId id of the cri that send the µSlice
      ** @param criobId id of the crob that send the µSlice (currently not used set to 0 062021 PR)
      ** @param istream
      ** @return CbmTrdRawMessageSpadic
      ** @todo Check if we can get rid of the future obsolete microslice stuff.
@@ -134,7 +134,7 @@ namespace cbm::algo::trd
    private:  // Types
     struct MsContext {
-      /** @brief Start time of the current µSlice relative to the Timeslice start time in Spadic CC. */
+      /** @brief Start time of the current micro-Slice relative to the Timeslice start time in Spadic CC. */
       size_t fMsStartTimeRelCC = 0;
 
@@ -162,8 +162,8 @@ namespace cbm::algo::trd
 
     /**
-     ** @brief Digest the flags of the currently unpacked µSlice.
-     ** @param flags flags stored in the µSlice descriptor
+     ** @brief Digest the flags of the currently unpacked micro-Slice.
+     ** @param flags flags stored in the micro-Slice descriptor
      ** @param storage of monitoring data
      **/
@@ -208,8 +208,8 @@ namespace cbm::algo::trd
      ** @brief Create a CbmTrdRawMessageSpadic from the hit message input.
      ** @param word
-     ** @param criId id of the cri that send the µSlice
-     ** @param criobId id of the crob that send the µSlice (currently not used set to 0 062021 PR)
+     ** @param criId id of the cri that send the micro-Slice
+     ** @param criobId id of the crob that send the micro-Slice (currently not used set to 0 062021 PR)
      ** @param istream
      ** @return CbmTrdRawMessageSpadic